OpenGL rendering engine, atlas management, and terminal grid.
Structs
- Cell
Data - Data for a single terminal cell including character and colors.
- Cell
Dynamic - Dynamic instance data for terminal cell appearance.
- Cell
Query - Configuration for querying and extracting text from terminal cells.
- Font
Atlas - Type-erased wrapper around any
Atlasimplementation. - GlState
- Manages simple GL state to reduce redundant state changes
- Glyph
Tracker - Tracks glyphs that were requested but not found in the font atlas.
- Render
Context - Rendering context that provides access to GL state.
- Selection
Tracker - Tracks the active text selection in the terminal grid.
- Static
Font Atlas - A texture atlas containing font glyphs for efficient GL text rendering.
- Terminal
Grid - A high-performance terminal grid renderer using instanced rendering.
Enums
- Cell
Iterator - Zero-allocation iterator over terminal cell indices.
- Glyph
Slot - Classifies a glyph’s texture slot by width category.
- Selection
Mode - Defines how cells are selected in the terminal grid.
Traits
Functions
- select
- Creates a new cell query with the specified selection mode.